# NeuralNetwork
Basic neural network, shamelessly stolen from https://medium.com/data-science/math-neural-network-from-scratch-in-python-d6da9f29ce65, and then some other stuff added on top.

# Virtual Environment
Windows Activation Command: .\venv\Scripts\activate
Save Required Dependencies: pip freeze > requirements.txt
Install Required Dependencies: pip install -r requirements.txt